@@ -8,7 +8,7 @@ package Object::Pad;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 
@@ -54,7 +54,7 @@ B<WARNING> This is a highly experimental proof-of-concept. Please don't
 actually use this in production :)
 
 This module provides a simple syntax for creating object classes, which uses
-private variables that look like lexicals as object member attributes.
+private variables that look like lexicals as object member fields.
 
 =head1 KEYWORDS
 
@@ -68,19 +68,31 @@ Behaves similarly to the C<package> keyword, but provides a package that
 defines a new class. Such a class provides an automatic constructor method
 called C<new>, which will invoke the class's C<CREATE> method if it exists.
 
+A single superclass is supported by the keyword C<extends>
+
+   class Cat extends Animal {
+      ...
+   }
+
+The superclass must also be implemented by C<Object::Pad>.
+
 =head2 has
 
    has $var;
    has @var;
    has %var;
 
-Declares that the instances of the class have a member attribute of the given
-name. This member attribute (called a "slot") will be accessible as a lexical
+Declares that the instances of the class have a member field of the given
+name. This member field (called a "slot") will be accessible as a lexical
 variable within any C<method> declarations in the class.
 
 Array and hash members are permitted and behave as expected; you do not need
 to store references to anonymous arrays or hashes.
 
+Member fields are private to a class. They are not visible to users of the
+class, nor to subclasses. In order to provide access to them a class may wish
+to use L</method> to create an accessor.
+
 =head2 method
 
    method NAME {
@@ -96,12 +108,21 @@ to store references to anonymous arrays or hashes.
    }
 
 Declares a new named method. This behaves similarly to the C<sub> keyword,
-except that within the body of the method all of the member attributes
-("slots") are also accessible. In addition, the method body will have a
-lexical called C<$self> which contains the invocant object directly; it will
-already have been shifted from the C<@_> array.
+except that within the body of the method all of the member fields ("slots")
+are also accessible. In addition, the method body will have a lexical called
+C<$self> which contains the invocant object directly; it will already have
+been shifted from the C<@_> array.
 
-The C<signatures> feature is automatically enabled for method declarations.
+The C<signatures> feature is automatically enabled for method declarations. In
+this case the signature does not have to account for the invocant instance; 
+that is handled directly.
+
+   method m($one, $two) {
+      say "$self invokes method on one=$one two=$two";
+   }
+
+   ...
+   $obj->m(1, 2);
 
 A list of attributes may be supplied as for C<sub>. The most useful of these
 is C<:lvalue>, allowing easy creation of read-write accessors for slots.
@@ -158,7 +179,15 @@ Setting default package using C<class Name;> statement without block.
 
 =item *
 
-Subclassing. Single-inheritence is easier than multi so maybe that first.
+Multiple inheritence of subclassing
+
+=item *
+
+Roles
+
+=item *
+
+Consider visibility of superclass slots to subclasses.
 
 =item *
 
